from setuptools import setup

setup(
    name='parser_module',
    version='4.16',
    packages=['parser_module'],
    author_email='ivan.frinom@gmail.com',
    install_requires=[
        'parser_libraries>=3.4'
    ]
)
